@@ -10,17 +10,17 @@
 #' @author Nandan L. Patil \email{tryanother609@@gmail.com}
 #' @details Gets todays bhavcopy from NSE. The function tries to get the bhavcopy from two sources Old and New website of NSE.
 #'
-#' @source <https://www1.nseindia.com/products/content/all_daily_reports.htm>, <https://www.bseindia.com/markets/marketinfo/BhavCopy.aspx>
+#' @source <https://www.nseindia.com/all-reports>, <https://www.bseindia.com/markets/marketinfo/BhavCopy.aspx>
 #'
 #' @seealso \code{\link[nser]{bhavpr}}\code{\link[nser]{bhav}}
 #'
-#' @import stats
 #' @importFrom utils download.file read.csv unzip
 #' @importFrom curl has_internet
 #'
 #' @export
-#' @examples \donttest{
-#' #Todays NSE Equity Bhavcopy
+#' @examples \dontrun{
+#'
+#' #Todays NSE Equity Bhavcopy, the data would be available usually after 6.30 PM.
 #' library(nser)
 #' report = bhavtoday()
 #'
@@ -73,8 +73,10 @@ bhavtoday = function(se = 'NSE')
   }
 
   if(se == 'NSE'){
-    df = nsebhav()
-  }else if(se == 'BSE') df = bsebhav()
+    df = tryCatch(nsebhav(), error=function(e) conditionMessage(w),
+                  warning = function(w) conditionMessage(w))
+  }else if(se == 'BSE') df = tryCatch(bsebhav(), error = function(e) conditionMessage(e),
+                                      warning = function(w) conditionMessage(w))
 
   return(df)
 }
